/*
 * Diskheap Sub-block Defines...
 *
 * Copyright 2002 by Gray Watson
 *
 * This file is part of the diskheap package.
 *
 * Permission to use, copy, modify, and distribute this software for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Gray Watson not be used in advertising
 * or publicity pertaining to distribution of the document or software
 * without specific, written prior permission.
 *
 * Gray Watson makes no representations about the suitability of the
 * software described herein for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * The author may be contacted via http://256.com/gray/
 *
 * $Id: diskheap_sub.h,v 1.3 2002/02/19 15:32:34 gray Exp $
 */

#ifndef __DISKHEAP_SUB_H__
#define __DISKHEAP_SUB_H__

#ifdef __cplusplus
extern "C" {
#if 0
}
#endif
#endif

/*<<<<<<<<<<  The below prototypes are auto-generated by fillproto */

/*
 * int _dh_account_alloc
 *
 * DESCRIPTION:
 *
 * Adjust the stats to account for an allocation.
 *
 * RETURNS:
 *
 * Success - DISKHEAP_ERROR_NONE
 *
 * Failure - DISKHEAP error code
 *
 * ARGUMENTS:
 *
 * dh_p <-> Pointer to the diskheap we are working on.
 *
 * block_n -> How many blocks we are using.  0 if none.
 *
 * size -> Size of the user allocation.
 *
 * end_b -> Set to 1 if the blocks were allocated at the end of the
 * heap.
 */
extern
int	_dh_account_alloc(diskheap_t *dh_p, const unsigned int block_n,
			 const unsigned int size, const int end_b);

/*
 * int _dh_account_delete
 *
 * DESCRIPTION:
 *
 * Adjust the stats to account for a deletion.
 *
 * RETURNS:
 *
 * Success - DISKHEAP_ERROR_NONE
 *
 * Failure - DISKHEAP error code
 *
 * ARGUMENTS:
 *
 * dh_p <-> Pointer to the diskheap we are working on.
 *
 * block_n -> How many blocks we are deleting.  0 if none.
 */
extern
int	_dh_account_delete(diskheap_t *dh_p, const unsigned int block_n);

/*
 * int _dh_sub_init
 *
 * DESCRIPTION:
 *
 * Initialize the sub-block allocation routines.
 *
 * RETURNS:
 *
 * Success - DISKHEAP_ERROR_NONE
 *
 * Failure - DISKHEAP error code
 *
 * ARGUMENTS:
 *
 * dh_p <-> Diskheap pointer we are initializing.
 */
extern
int	_dh_sub_init(diskheap_t *dh_p);

/*
 * int _dh_sub_store
 *
 * DESCRIPTION:
 *
 * Store a sub-block sized piece of memory.
 *
 * RETURNS:
 *
 * Success - DISKHEAP_ERROR_NONE
 *
 * Failure - DISKHEAP error code
 *
 * ARGUMENTS:
 *
 * dh_p <-> Pointer to a diskheap structure.
 *
 * buffer -> Buffer of anonymous memory to be written to disk.
 *
 * user_size -> Size of buffer in bytes.  Must be > 0.
 *
 * user_type -> Type number to be associated with the buffer that is
 * being stored.  This number will be returned when you retrieve the
 * block and can be used to verify that you are dealing with the right
 * kind of storage chunk.  Pass in 0 if none is desired.
 *
 * block_num_p <- Pointer to an unsigned int which be set to the block
 * number of the allocation.  Both the block-number and the offset are
 * needed to read the information later.  This argument cannot be
 * NULL.
 *
 * offset_np <- Pointer to an unsigned int which be set to the offset
 * inside of the block of the allocation.  Both the block-number and
 * the offset are needed to read the information later.  This argument
 * cannot be NULL.
 */
extern
int	_dh_sub_store(diskheap_t *dh_p, const void *buffer,
		      const unsigned int user_size,
		      const unsigned int user_type,
		      unsigned int *block_num_p, unsigned int *offset_p);

/*
 * int _dh_sub_delete
 *
 * DESCRIPTION:
 *
 * Delete a previously stored sub-block allocation.
 *
 * RETURNS:
 *
 * Success - DISKHEAP_ERROR_NONE
 *
 * Failure - DISKHEAP error code
 *
 * ARGUMENTS:
 *
 * dh_p <-> Pointer to a diskheap structure.
 *
 * block_num -> Block-number of the allocation we are deleting.
 *
 * offset -> Offset inside of the block of the allocation we are
 * deleting.
 *
 * user_size_p <- Size of the user allocation in bytes.
 *
 * user_type_p <- Type number associated with the buffer by
 * diskheap_store.
 */
extern
int	_dh_sub_delete(diskheap_t *dh_p, const unsigned int block_num,
		       const unsigned int offset,
		       unsigned int *user_size_p,
		       unsigned int *user_type_p);

/*<<<<<<<<<<   This is end of the auto-generated output from fillproto. */

#ifdef __cplusplus
}
#endif


#endif /* ! __DISKHEAP_SUB_H__ */
